Get the number of rows of a large file without reading it into memory.
See also
Other general:
createDT(),
fillNA_CS_PP(),
get_os(),
is_empty()
Get the number of rows of a large file without reading it into memory.
Other general:
createDT(),
fillNA_CS_PP(),
get_os(),
is_empty()