Ensure two data.table are merged properly. Necessary due to inconsistencies with how data.table are evaluated in different scopes.
Arguments
- x, y
data tables.yis coerced to adata.tableif it isn't one already.- by
A vector of shared column names in
xandyto merge on. This defaults to the shared key columns between the two tables. Ifyhas no key columns, this defaults to the key ofx.- dup_stop
Throw an error if duplicates of the
bycolumn are detected after merging.- na_stop
Throw an error if all of the data from
yhas been converted to NAs (unless they were all NAs before merging).- ...
Additional arguments passed to merge.data.table.