Identify columns that are lists and turn them into vectors.
Arguments
- dt
A data.table.
- exclude
Columns to exclude from unlisting.
- verbose
Print messages.
Identify columns that are lists and turn them into vectors.
A data.table.
Columns to exclude from unlisting.
Print messages.